@@ -123,10 +123,19 @@ nlmixr2Est.predict <- function(env, ...) {
 
 #' @export
 predict.nlmixr2FitCore <- function(object, ...) {
-  .both <- .getControlFromDots(rxode2::rxControl(), ...)
+  .env <- .nlmixrEvalEnv$envir
+  if (!is.environment(.env)) {
+    .env <- parent.frame(1)
+  }
+  .both <- .getControlFromDots(rxode2::rxControl(envir=.env), ...)
   .both$ctl$omega <- NA
   .both$ctl$sigma <- NA
+  .env <- .nlmixrEvalEnv$envir
+  if (!is.environment(.env)) {
+    .env <- parent.frame(1)
+  }
   .rxControl <- do.call(rxode2::rxControl, .both$ctl)
+  .rxControl$envir <- .env
   if (inherits(.both$rest$newdata, "data.frame")) {
     nlmixr2(object=object, data=.both$rest$newdata,
             est="rxSolve", control=.rxControl)
@@ -137,8 +146,13 @@ predict.nlmixr2FitCore <- function(object, ...) {
 
 #' @export
 simulate.nlmixr2FitCore <- function(object, ...) {
-  .both <- .getControlFromDots(rxode2::rxControl(), ...)
+  .env <- .nlmixrEvalEnv$envir
+  if (!is.environment(.env)) {
+    .env <- parent.frame(1)
+  }
+  .both <- .getControlFromDots(rxode2::rxControl(envir=.env), ...)
   .rxControl <- do.call(rxode2::rxControl, .both$ctl)
+  .rxControl$envir <- .env
   if (inherits(.both$rest$newdata, "data.frame")) {
     nlmixr2(object=object, data=.both$rest$newdata,
             est="rxSolve", control=.rxControl)
