@@ -994,10 +994,10 @@ public:
       mprior_phi0.set_size(N, nphi0);                              // deal w/ nphi0=0
 
       mat G1=(statphi12+mprior_phi1.t()*mprior_phi1- statphi11.t()*mprior_phi1 - mprior_phi1.t()*statphi11)/N;
-      if (kiter<=(unsigned int)(nb_sa)) { 
+      if (kiter<=(unsigned int)(nb_sa)) {
         Gamma2_phi1=max(Gamma2_phi1*coef_sa, diagmat(G1));
       } else {
-        Gamma2_phi1=G1;        
+        Gamma2_phi1=G1;
       }
       Gamma2_phi1=Gamma2_phi1%covstruct1;
       vec Gmin=minv(i1);
@@ -1809,7 +1809,7 @@ private:
   mat par_hist;
   uvec parHistThetaKeep;
   uvec parHistOmegaKeep;
-  
+
   int distribution;
 
   int nendpnt;
@@ -2028,7 +2028,6 @@ mat user_function(const mat &_phi, const mat &_evt, const List &_opt) {
   mat g(_rx->nobs2, 3); // nobs EXCLUDING EVID=2
   int elt=0;
   bool hasNan = false;
-  unsigned int nNanWarn=0;
   for (int id = 0; id < _Nnlmixr2; ++id) {
     ind = &(_rx->subjects[id]);
     iniSubjectE(op->neq, 1, ind, op, _rx, saem_inis);
@@ -2086,7 +2085,6 @@ mv_t rxModelVarsS;
 
 void setupRx(List &opt, SEXP evt, SEXP evtM) {
   RObject obj = opt[".rx"];
-  bool doIni = false;
   if (getRx_ == NULL) {
     getRx_ = (getRxSolve_t) R_GetCCallable("rxode2","getRxSolve_");
     getTimeS = (getTime_t) R_GetCCallable("rxode2", "getTime");
@@ -2097,7 +2095,6 @@ void setupRx(List &opt, SEXP evt, SEXP evtM) {
     iniSubjectE = (iniSubjectE_t) R_GetCCallable("rxode2","iniSubjectE");
     rxGetIdS = (rxGetId_t) R_GetCCallable("rxode2", "rxGetId");
     rxModelVarsS = (mv_t)R_GetCCallable("rxode2", "_rxode2_rxModelVars_");
-    doIni=true;
   }
   List mv = rxModelVarsS(obj);
   parNames = mv[RxMv_params];
